@@ -15,11 +15,11 @@
 #    under the License.
 
 from oslo_log import log
-import six
 import webob.dec
 import webob.exc
 
 from manila.api.openstack import wsgi
+from manila.i18n import _
 from manila import utils
 from manila.wsgi import common as base_wsgi
 
@@ -40,6 +40,11 @@ class FaultWrapper(base_wsgi.Middleware):
             status, webob.exc.HTTPInternalServerError)()
 
     def _error(self, inner, req):
+        if isinstance(inner, UnicodeDecodeError):
+            msg = _("Error decoding your request. Either the URL or the "
+                    "request body contained characters that could not be "
+                    "decoded by Manila.")
+            return wsgi.Fault(webob.exc.HTTPBadRequest(explanation=msg))
         LOG.exception("Caught error: %s", inner)
 
         safe = getattr(inner, 'safe', False)
@@ -62,7 +67,7 @@ class FaultWrapper(base_wsgi.Middleware):
         # including those that are safe to expose, see bug 1021373
         if safe:
             outer.explanation = '%s: %s' % (inner.__class__.__name__,
-                                            six.text_type(inner))
+                                            inner)
         return wsgi.Fault(outer)
 
     @webob.dec.wsgify(RequestClass=wsgi.Request)
