@@ -11,14 +11,15 @@
 # under the License.
 
 """The group type API controller module."""
+import ast
 
-from oslo_utils import strutils
+from http import client as http_client
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
 import webob
 from webob import exc
 
+from manila.api import common
+from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.views import share_group_types as views
 from manila import exception
@@ -54,7 +55,7 @@ class ShareGroupTypesController(wsgi.Controller):
         return self._index(req)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def index(self, req):  # pylint: disable=function-redefined
+    def index(self, req):  # pylint: disable=function-redefined  # noqa F811
         return self._index(req)
 
     @wsgi.Controller.authorize('show')
@@ -67,7 +68,7 @@ class ShareGroupTypesController(wsgi.Controller):
             msg = _("Share group type with id %s not found.")
             raise exc.HTTPNotFound(explanation=msg % id)
 
-        share_group_type['id'] = six.text_type(share_group_type['id'])
+        share_group_type['id'] = str(share_group_type['id'])
         return self._view_builder.show(req, share_group_type)
 
     @wsgi.Controller.api_version('2.31', '2.54', experimental=True)
@@ -75,7 +76,7 @@ class ShareGroupTypesController(wsgi.Controller):
         return self._show(req, id)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def show(self, req, id):  # pylint: disable=function-redefined
+    def show(self, req, id):  # pylint: disable=function-redefined  # noqa F811
         return self._show(req, id)
 
     @wsgi.Controller.authorize('default')
@@ -87,7 +88,7 @@ class ShareGroupTypesController(wsgi.Controller):
             msg = _("Default share group type not found.")
             raise exc.HTTPNotFound(explanation=msg)
 
-        share_group_type['id'] = six.text_type(share_group_type['id'])
+        share_group_type['id'] = str(share_group_type['id'])
         return self._view_builder.show(req, share_group_type)
 
     @wsgi.Controller.api_version('2.31', '2.54', experimental=True)
@@ -95,7 +96,7 @@ class ShareGroupTypesController(wsgi.Controller):
         return self._default(req)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def default(self, req):  # pylint: disable=function-redefined
+    def default(self, req):  # pylint: disable=function-redefined  # noqa F811
         return self._default(req)
 
     def _get_share_group_types(self, req):
@@ -104,35 +105,27 @@ class ShareGroupTypesController(wsgi.Controller):
         context = req.environ['manila.context']
         if context.is_admin:
             # Only admin has query access to all group types
-            filters['is_public'] = self._parse_is_public(
+            filters['is_public'] = common.parse_is_public(
                 req.params.get('is_public'))
         else:
             filters['is_public'] = True
+
+        group_specs = req.params.get('group_specs', {})
+        group_specs_disallowed = (req.api_version_request <
+                                  api_version.APIVersionRequest("2.66"))
+
+        if group_specs and group_specs_disallowed:
+            msg = _("Filter by 'group_specs' is not supported by this "
+                    "microversion. Use 2.66 or greater microversion to "
+                    "be able to use filter search by 'group_specs.")
+            raise webob.exc.HTTPBadRequest(explanation=msg)
+        elif group_specs:
+            filters['group_specs'] = ast.literal_eval(group_specs)
+
         limited_types = share_group_types.get_all(
             context, search_opts=filters).values()
         return list(limited_types)
 
-    @staticmethod
-    def _parse_is_public(is_public):
-        """Parse is_public into something usable.
-
-        :returns:
-            - True: API should list public share group types only
-            - False: API should list private share group types only
-            - None: API should list both public and private share group types
-        """
-        if is_public is None:
-            # preserve default value of showing only public types
-            return True
-        elif six.text_type(is_public).lower() == "all":
-            return None
-        else:
-            try:
-                return strutils.bool_from_string(is_public, strict=True)
-            except ValueError:
-                msg = _('Invalid is_public filter [%s]') % is_public
-                raise exc.HTTPBadRequest(explanation=msg)
-
     @wsgi.Controller.authorize('create')
     def _create(self, req, body):
         """Creates a new share group type."""
@@ -158,7 +151,7 @@ class ShareGroupTypesController(wsgi.Controller):
             raise webob.exc.HTTPBadRequest(explanation=msg)
         if specs:
             for element in list(specs.keys()) + list(specs.values()):
-                if not isinstance(element, six.string_types):
+                if not isinstance(element, str):
                     msg = _("Group specs keys and values should be strings.")
                     raise webob.exc.HTTPBadRequest(explanation=msg)
         try:
@@ -167,9 +160,9 @@ class ShareGroupTypesController(wsgi.Controller):
             share_group_type = share_group_types.get_by_name(
                 context, name)
         except exception.ShareGroupTypeExists as err:
-            raise webob.exc.HTTPConflict(explanation=six.text_type(err))
+            raise webob.exc.HTTPConflict(explanation=err.message)
         except exception.ShareTypeDoesNotExist as err:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
+            raise webob.exc.HTTPNotFound(explanation=err.message)
         except exception.NotFound:
             raise webob.exc.HTTPNotFound()
         return self._view_builder.show(req, share_group_type)
@@ -181,7 +174,7 @@ class ShareGroupTypesController(wsgi.Controller):
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action("create")
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         return self._create(req, body)
 
     @wsgi.Controller.authorize('delete')
@@ -205,7 +198,7 @@ class ShareGroupTypesController(wsgi.Controller):
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action("delete")
-    def delete(self, req, id):  # pylint: disable=function-redefined
+    def delete(self, req, id):  # pylint: disable=function-redefined  # noqa F811
         return self._delete(req, id)
 
     @wsgi.Controller.authorize('list_project_access')
@@ -236,7 +229,7 @@ class ShareGroupTypesController(wsgi.Controller):
 
     # pylint: disable=function-redefined
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def share_group_type_access(self, req, id):
+    def share_group_type_access(self, req, id):  # noqa F811
         return self._share_group_type_access(req, id)
 
     @wsgi.Controller.authorize('add_project_access')
@@ -249,7 +242,7 @@ class ShareGroupTypesController(wsgi.Controller):
             share_group_types.add_share_group_type_access(
                 context, id, project)
         except exception.ShareGroupTypeAccessExists as err:
-            raise webob.exc.HTTPConflict(explanation=six.text_type(err))
+            raise webob.exc.HTTPConflict(explanation=err.message)
         return webob.Response(status_int=http_client.ACCEPTED)
 
     # pylint: enable=function-redefined
@@ -261,7 +254,7 @@ class ShareGroupTypesController(wsgi.Controller):
     # pylint: disable=function-redefined
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action('addProjectAccess')
-    def add_project_access(self, req, id, body):
+    def add_project_access(self, req, id, body):  # noqa F811
         return self._add_project_access(req, id, body)
 
     @wsgi.Controller.authorize('remove_project_access')
@@ -274,7 +267,7 @@ class ShareGroupTypesController(wsgi.Controller):
             share_group_types.remove_share_group_type_access(
                 context, id, project)
         except exception.ShareGroupTypeAccessNotFound as err:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
+            raise webob.exc.HTTPNotFound(explanation=err.message)
         return webob.Response(status_int=http_client.ACCEPTED)
 
     # pylint: enable=function-redefined
@@ -286,7 +279,7 @@ class ShareGroupTypesController(wsgi.Controller):
     # pylint: disable=function-redefined
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action('removeProjectAccess')
-    def remove_project_access(self, req, id, body):
+    def remove_project_access(self, req, id, body):  # noqa F811
         return self._remove_project_access(req, id, body)
 
     def _assert_non_public_share_group_type(self, context, type_id):
@@ -298,7 +291,7 @@ class ShareGroupTypesController(wsgi.Controller):
                         "public share group type.")
                 raise webob.exc.HTTPConflict(explanation=msg)
         except exception.ShareGroupTypeNotFound as err:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
+            raise webob.exc.HTTPNotFound(explanation=err.message)
 
 
 def create_resource():
