@@ -194,20 +194,38 @@ class ShareController(wsgi.Controller,
 
         return data
 
-    @wsgi.Controller.api_version("2.65")
+    @wsgi.Controller.api_version("2.90")
     def create(self, req, body):
         if not self.is_valid_body(body, 'share'):
             raise exc.HTTPUnprocessableEntity()
 
+        share = body['share']
+        scheduler_hints = share.pop('scheduler_hints', None)
+        encryption_key_ref = share.pop('encryption_key_ref', None)
+
+        return self._create(
+            req, body,
+            check_create_share_from_snapshot_support=True,
+            check_availability_zones_extra_spec=True,
+            scheduler_hints=scheduler_hints,
+            encryption_key_ref=encryption_key_ref)
+
+    @wsgi.Controller.api_version("2.65", "2.89")
+    def create(self, req, body): # pylint: disable=function-redefined  # noqa F811
+        if not self.is_valid_body(body, 'share'):
+            raise exc.HTTPUnprocessableEntity()
+
         share = body['share']
         scheduler_hints = share.pop('scheduler_hints', None)
         if req.api_version_request < api_version.APIVersionRequest("2.67"):
             if scheduler_hints:
                 scheduler_hints.pop('only_host', None)
-        return self._create(req, body,
-                            check_create_share_from_snapshot_support=True,
-                            check_availability_zones_extra_spec=True,
-                            scheduler_hints=scheduler_hints)
+
+        return self._create(
+            req, body,
+            check_create_share_from_snapshot_support=True,
+            check_availability_zones_extra_spec=True,
+            scheduler_hints=scheduler_hints)
 
     @wsgi.Controller.api_version("2.48", "2.64") # noqa
     def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
@@ -605,6 +623,9 @@ class ShareController(wsgi.Controller,
         if req.api_version_request < api_version.APIVersionRequest("2.69"):
             req.GET.pop('is_soft_deleted', None)
 
+        if req.api_version_request < api_version.APIVersionRequest("2.90"):
+            req.GET.pop('encryption_key_ref', None)
+
         return self._get_shares(req, is_detail=False)
 
     @wsgi.Controller.api_version("2.0")
@@ -623,13 +644,16 @@ class ShareController(wsgi.Controller,
         if req.api_version_request < api_version.APIVersionRequest("2.69"):
             req.GET.pop('is_soft_deleted', None)
 
+        if req.api_version_request < api_version.APIVersionRequest("2.90"):
+            req.GET.pop('encryption_key_ref', None)
+
         return self._get_shares(req, is_detail=True)
 
     def _validate_metadata_for_update(self, req, share_id, metadata,
                                       delete=True):
-        admin_metadata_ignore_keys = set(self._conf_admin_only_metadata_keys)
+        persistent_keys = set(self._conf_admin_only_metadata_keys)
         context = req.environ['manila.context']
-        if set(metadata).intersection(admin_metadata_ignore_keys):
+        if set(metadata).intersection(persistent_keys):
             try:
                 policy.check_policy(
                     context, 'share', 'update_admin_only_metadata')
@@ -637,17 +661,17 @@ class ShareController(wsgi.Controller,
                 msg = _("Cannot set or update admin only metadata.")
                 LOG.exception(msg)
                 raise exc.HTTPForbidden(explanation=msg)
-            admin_metadata_ignore_keys = []
+            persistent_keys = []
 
         current_share_metadata = db.share_metadata_get(context, share_id)
         if delete:
             _metadata = metadata
-            for key in admin_metadata_ignore_keys:
+            for key in persistent_keys:
                 if key in current_share_metadata:
                     _metadata[key] = current_share_metadata[key]
         else:
             metadata_copy = metadata.copy()
-            for key in admin_metadata_ignore_keys:
+            for key in persistent_keys:
                 metadata_copy.pop(key, None)
             _metadata = current_share_metadata.copy()
             _metadata.update(metadata_copy)
@@ -671,7 +695,12 @@ class ShareController(wsgi.Controller,
                                                        body['metadata'],
                                                        delete=False)
         body['metadata'] = _metadata
-        return self._create_metadata(req, resource_id, body)
+        metadata = self._create_metadata(req, resource_id, body)
+
+        context = req.environ['manila.context']
+        self.share_api.update_share_from_metadata(context, resource_id,
+                                                  metadata.get('metadata'))
+        return metadata
 
     @wsgi.Controller.api_version("2.0")
     @wsgi.Controller.authorize("update_share_metadata")
@@ -682,7 +711,12 @@ class ShareController(wsgi.Controller,
         _metadata = self._validate_metadata_for_update(req, resource_id,
                                                        body['metadata'])
         body['metadata'] = _metadata
-        return self._update_all_metadata(req, resource_id, body)
+        metadata = self._update_all_metadata(req, resource_id, body)
+
+        context = req.environ['manila.context']
+        self.share_api.update_share_from_metadata(context, resource_id,
+                                                  metadata.get('metadata'))
+        return metadata
 
     @wsgi.Controller.api_version("2.0")
     @wsgi.Controller.authorize("update_share_metadata")
@@ -694,7 +728,12 @@ class ShareController(wsgi.Controller,
                                                        body['metadata'],
                                                        delete=False)
         body['metadata'] = _metadata
-        return self._update_metadata_item(req, resource_id, body, key)
+        metadata = self._update_metadata_item(req, resource_id, body, key)
+
+        context = req.environ['manila.context']
+        self.share_api.update_share_from_metadata(context, resource_id,
+                                                  metadata.get('metadata'))
+        return metadata
 
     @wsgi.Controller.api_version("2.0")
     @wsgi.Controller.authorize("get_share_metadata")
