@@ -386,6 +386,11 @@ def share_instance_get_all_by_share_group_id(context, share_group_id):
     return IMPL.share_instance_get_all_by_share_group_id(
         context, share_group_id)
 
+
+def share_instance_sizes_sum_by_host(context, host):
+    """Returns sum of sizes of all share instances on given host."""
+    return IMPL.share_instance_sizes_sum_by_host(context, host)
+
 ###################
 
 
@@ -1892,3 +1897,15 @@ def resource_lock_get(context, lock_id):
 def resource_lock_get_all(context, **kwargs):
     """Retrieve all resource locks."""
     return IMPL.resource_lock_get_all(context, **kwargs)
+
+##################
+
+
+def encryption_keys_get_count(context, filters=None):
+    """Get count of encryption keys."""
+    return IMPL.encryption_keys_get_count(context, filters=filters)
+
+
+def encryption_keys_get_all(context, filters=None):
+    """Get all encryption keys."""
+    return IMPL.encryption_keys_get_all(context, filters=filters)
