@@ -100,23 +100,25 @@ class Manager(base.Base, PeriodicTasks):
         """Tasks to be run at a periodic interval."""
         return self.run_periodic_tasks(context, raise_on_error=raise_on_error)
 
-    def init_host(self):
+    def init_host(self, service_id=None):
         """Handle initialization if this is a standalone service.
 
         A hook point for services to execute tasks before the services are made
         available (i.e. showing up on RPC and starting to accept RPC calls) to
         other components.  Child classes should override this method.
 
+        :param service_id: ID of the service where the manager is running.
         """
         pass
 
-    def init_host_with_rpc(self):
+    def init_host_with_rpc(self, service_id=None):
         """A hook for service to do jobs after RPC is ready.
 
         Like init_host(), this method is a hook where services get a chance
         to execute tasks that *need* RPC. Child classes should override
         this method.
 
+        :param service_id: ID of the service where the manager is running.
         """
         pass
 
