@@ -19,7 +19,7 @@ from manila.policies import base
 BASE_POLICY_NAME = 'share_server:%s'
 
 DEPRECATED_REASON = """
-The share server API now supports system scope and default roles.
+The share server API now supports scope and default roles.
 """
 
 deprecated_server_index = policy.DeprecatedRule(
@@ -105,14 +105,10 @@ deprecated_server_reset_task_state = policy.DeprecatedRule(
 share_server_policies = [
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'index',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Get share servers.",
         operations=[
-            {
-                'method': 'GET',
-                'path': '/share-servers',
-            },
             {
                 'method': 'GET',
                 'path': '/share-servers?{query}',
@@ -122,8 +118,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'show',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Show share server.",
         operations=[
             {
@@ -135,8 +131,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'details',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Get share server details.",
         operations=[
             {
@@ -148,8 +144,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'delete',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Delete share server.",
         operations=[
             {
@@ -161,8 +157,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'manage_share_server',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Manage share server.",
         operations=[
             {
@@ -174,8 +170,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'unmanage_share_server',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Unmanage share server.",
         operations=[
             {
@@ -187,8 +183,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'reset_status',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Reset the status of a share server.",
         operations=[
             {
@@ -200,8 +196,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_migration_start',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Migrates a share server to the specified host.",
         operations=[
             {
@@ -213,8 +209,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_migration_check',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Check if can migrates a share server to the specified "
                     "host.",
         operations=[
@@ -227,8 +223,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_migration_complete',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Invokes the 2nd phase of share server migration.",
         operations=[
             {
@@ -240,8 +236,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_migration_cancel',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description="Attempts to cancel share server migration.",
         operations=[
             {
@@ -253,8 +249,8 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_migration_get_progress',
-        check_str=base.SYSTEM_READER,
-        scope_types=['system'],
+        check_str=base.ADMIN,
+        scope_types=['project'],
         description=("Retrieves the share server migration progress for a "
                      "given share server."),
         operations=[
@@ -267,9 +263,9 @@ share_server_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'share_server_reset_task_state',
-        check_str=base.SYSTEM_ADMIN,
-        scope_types=['system'],
-        description=("Resets task state."),
+        check_str=base.ADMIN,
+        scope_types=['project'],
+        description="Resets task state.",
         operations=[
             {
                 'method': 'POST',
