@@ -19,7 +19,7 @@ from manila.policies import base
 BASE_POLICY_NAME = 'share_snapshot_export_location:%s'
 
 DEPRECATED_REASON = """
-The share snapshot location API now supports system scope and default roles.
+The share snapshot location API now supports scope and default roles.
 """
 
 deprecated_snapshot_location_index = policy.DeprecatedRule(
@@ -39,8 +39,8 @@ deprecated_snapshot_location_show = policy.DeprecatedRule(
 share_snapshot_export_location_policies = [
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'index',
-        check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        check_str=base.ADMIN_OR_PROJECT_READER,
+        scope_types=['project'],
         description="List export locations of a share snapshot.",
         operations=[
             {
@@ -52,8 +52,8 @@ share_snapshot_export_location_policies = [
     ),
     policy.DocumentedRuleDefault(
         name=BASE_POLICY_NAME % 'show',
-        check_str=base.SYSTEM_OR_PROJECT_READER,
-        scope_types=['system', 'project'],
+        check_str=base.ADMIN_OR_PROJECT_READER,
+        scope_types=['project'],
         description="Get details of a specified export location of a "
                     "share snapshot.",
         operations=[
