@@ -277,7 +277,8 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
         # Is there a sync in progress? If yes, ignore the incoming request.
         rule_filter = {
             'state': (constants.ACCESS_STATE_APPLYING,
-                      constants.ACCESS_STATE_DENYING),
+                      constants.ACCESS_STATE_DENYING,
+                      constants.ACCESS_STATE_UPDATING),
         }
         syncing_rules = self.get_and_update_share_instance_access_rules(
             context, filters=rule_filter, share_instance_id=share_instance_id)
@@ -288,11 +289,11 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                    "be applied shortly.")
             LOG.debug(msg, msg_payload)
         else:
-            rules_to_apply_or_deny = (
+            rules_to_apply_or_update_or_deny = (
                 self._update_and_get_unsynced_access_rules_from_db(
                     context, share_instance_id)
             )
-            if rules_to_apply_or_deny:
+            if rules_to_apply_or_update_or_deny:
                 msg = ("Updating access rules for share instance %(si)s "
                        "belonging to share %(shr)s.")
                 LOG.debug(msg, msg_payload)
@@ -320,30 +321,33 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
 
         rules_to_be_removed_from_db = []
         # Populate rules to send to the driver
-        (access_rules_to_be_on_share, add_rules, delete_rules) = (
+        (access_rules_on_share, add_rules, delete_rules, update_rules) = (
             self._get_rules_to_send_to_driver(context, share_instance)
         )
 
         if share_instance['cast_rules_to_readonly']:
             # Ensure read/only semantics for a migrating instances
-            access_rules_to_be_on_share = self._set_rules_to_readonly(
-                access_rules_to_be_on_share, share_instance)
+            access_rules_on_share = self._set_rules_to_readonly(
+                access_rules_on_share, share_instance)
             add_rules = []
             rules_to_be_removed_from_db = delete_rules
             delete_rules = []
+            update_rules = []
 
         try:
             driver_rule_updates = self._update_rules_through_share_driver(
-                context, share_instance, access_rules_to_be_on_share,
-                add_rules, delete_rules, rules_to_be_removed_from_db,
+                context, share_instance, access_rules_on_share,
+                add_rules, delete_rules, update_rules,
+                rules_to_be_removed_from_db,
                 share_server)
 
             self.process_driver_rule_updates(
                 context, driver_rule_updates, share_instance_id)
 
-            # Update access rules that are still in 'applying' state
+            # Update access rules that are still in 'applying/updating' state
             conditionally_change = {
                 constants.ACCESS_STATE_APPLYING: constants.ACCESS_STATE_ACTIVE,
+                constants.ACCESS_STATE_UPDATING: constants.ACCESS_STATE_ACTIVE,
             }
             self.get_and_update_share_instance_access_rules(
                 context, share_instance_id=share_instance_id,
@@ -353,6 +357,7 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
             conditionally_change_rule_state = {
                 constants.ACCESS_STATE_APPLYING: constants.ACCESS_STATE_ERROR,
                 constants.ACCESS_STATE_DENYING: constants.ACCESS_STATE_ERROR,
+                constants.ACCESS_STATE_UPDATING: constants.ACCESS_STATE_ERROR,
             }
             self.get_and_update_share_instance_access_rules(
                 context, share_instance_id=share_instance_id,
@@ -387,6 +392,7 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
     def _update_rules_through_share_driver(self, context, share_instance,
                                            access_rules_to_be_on_share,
                                            add_rules, delete_rules,
+                                           update_rules,
                                            rules_to_be_removed_from_db,
                                            share_server):
         driver_rule_updates = {}
@@ -395,6 +401,7 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                 share_protocol == 'nfs'):
             add_rules = self._filter_ipv6_rules(add_rules)
             delete_rules = self._filter_ipv6_rules(delete_rules)
+            update_rules = self._filter_ipv6_rules(update_rules)
             access_rules_to_be_on_share = self._filter_ipv6_rules(
                 access_rules_to_be_on_share)
         try:
@@ -404,11 +411,14 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                 access_rules_to_be_on_share,
                 add_rules=add_rules,
                 delete_rules=delete_rules,
+                update_rules=update_rules,
                 share_server=share_server
             ) or {}
         except NotImplementedError:
             # NOTE(u_glide): Fallback to legacy allow_access/deny_access
             # for drivers without update_access() method support
+            # It is also possible that updating the access_level is not
+            # permitted.
             self._update_access_fallback(context, add_rules, delete_rules,
                                          rules_to_be_removed_from_db,
                                          share_instance,
@@ -464,6 +474,7 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                 conditional_state_updates = {
                     constants.ACCESS_STATE_APPLYING: state,
                     constants.ACCESS_STATE_DENYING: state,
+                    constants.ACCESS_STATE_UPDATING: state,
                     constants.ACCESS_STATE_ACTIVE: state,
                 }
             else:
@@ -501,10 +512,12 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
     def _get_rules_to_send_to_driver(self, context, share_instance):
         add_rules = []
         delete_rules = []
+        update_rules = []
         access_filters = {
             'state': (constants.ACCESS_STATE_APPLYING,
                       constants.ACCESS_STATE_ACTIVE,
-                      constants.ACCESS_STATE_DENYING),
+                      constants.ACCESS_STATE_DENYING,
+                      constants.ACCESS_STATE_UPDATING),
         }
         existing_rules_in_db = self.get_and_update_share_instance_access_rules(
             context, filters=access_filters,
@@ -516,11 +529,14 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                 add_rules.append(rule)
             elif rule['state'] == constants.ACCESS_STATE_DENYING:
                 delete_rules.append(rule)
+            elif rule['state'] == constants.ACCESS_STATE_UPDATING:
+                update_rules.append(rule)
         delete_rule_ids = [r['id'] for r in delete_rules]
         access_rules_to_be_on_share = [
             r for r in existing_rules_in_db if r['id'] not in delete_rule_ids
         ]
-        return access_rules_to_be_on_share, add_rules, delete_rules
+        return (access_rules_to_be_on_share, add_rules,
+                delete_rules, update_rules)
 
     def _check_needs_refresh(self, context, share_instance_id):
         rules_to_apply_or_deny = (
@@ -567,13 +583,16 @@ class ShareInstanceAccess(ShareInstanceAccessDatabaseMixin):
                                                       share_instance_id):
         rule_filter = {
             'state': (constants.ACCESS_STATE_QUEUED_TO_APPLY,
-                      constants.ACCESS_STATE_QUEUED_TO_DENY),
+                      constants.ACCESS_STATE_QUEUED_TO_DENY,
+                      constants.ACCESS_STATE_QUEUED_TO_UPDATE),
         }
         conditionally_change = {
             constants.ACCESS_STATE_QUEUED_TO_APPLY:
                 constants.ACCESS_STATE_APPLYING,
             constants.ACCESS_STATE_QUEUED_TO_DENY:
                 constants.ACCESS_STATE_DENYING,
+            constants.ACCESS_STATE_QUEUED_TO_UPDATE:
+                constants.ACCESS_STATE_UPDATING,
         }
         rules_to_apply_or_deny = (
             self.get_and_update_share_instance_access_rules(
