@@ -44,9 +44,10 @@ from manila import utils
      8.0.0 - Supports manage/unmanage share server/share/snapshot
      9.0.0 - Implements default filter function
      9.0.1 - Bugfix: remove enable ace process when creating cifs share
+     9.0.2 - Bugfix: fix the driver startup issue with LACP ports configured
 """
 
-VERSION = "9.0.1"
+VERSION = "9.0.2"
 
 LOG = log.getLogger(__name__)
 SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
@@ -93,6 +94,7 @@ class UnityStorageConnection(driver.StorageConnection):
         self.nas_server_pool = None
         self.reserved_percentage = None
         self.reserved_snapshot_percentage = None
+        self.reserved_share_extend_percentage = None
         self.max_over_subscription_ratio = None
         self.port_ids_conf = None
         self.unity_share_server = None
@@ -135,6 +137,11 @@ class UnityStorageConnection(driver.StorageConnection):
         if self.reserved_snapshot_percentage is None:
             self.reserved_snapshot_percentage = self.reserved_percentage
 
+        self.reserved_share_extend_percentage = config.safe_get(
+            'reserved_share_extend_percentage')
+        if self.reserved_share_extend_percentage is None:
+            self.reserved_share_extend_percentage = self.reserved_percentage
+
         self.max_over_subscription_ratio = config.safe_get(
             'max_over_subscription_ratio')
         self.port_ids_conf = config.safe_get('unity_ethernet_ports')
@@ -593,6 +600,8 @@ class UnityStorageConnection(driver.StorageConnection):
                     'reserved_percentage': self.reserved_percentage,
                     'reserved_snapshot_percentage':
                         self.reserved_snapshot_percentage,
+                    'reserved_share_extend_percentage':
+                        self.reserved_share_extend_percentage,
                     'max_over_subscription_ratio':
                         self.max_over_subscription_ratio,
                 }
