@@ -31,13 +31,11 @@ infortrend_nas_opts = [
                default='manila',
                help='User for the Infortrend NAS server.'),
     cfg.StrOpt('infortrend_nas_password',
-               default=None,
                secret=True,
                help='Password for the Infortrend NAS server. '
                'This is not necessary '
                'if infortrend_nas_ssh_key is set.'),
     cfg.StrOpt('infortrend_nas_ssh_key',
-               default=None,
                help='SSH key for the Infortrend NAS server. '
                'This is not necessary '
                'if infortrend_nas_password is set.'),
@@ -123,13 +121,16 @@ class InfortrendNASDriver(driver.ShareDriver):
             reserved_snapshot_percentage=(
                 self.configuration.reserved_share_from_snapshot_percentage
                 or self.configuration.reserved_share_percentage),
+            reserved_share_extend_percentage=(
+                self.configuration.reserved_share_extend_percentage
+                or self.configuration.reserved_share_percentage),
             pools=self.ift_nas.update_pools_stats())
         LOG.debug('Infortrend pools status: %s', data['pools'])
 
         super(InfortrendNASDriver, self)._update_share_stats(data)
 
     def update_access(self, context, share, access_rules, add_rules,
-                      delete_rules, share_server=None):
+                      delete_rules, update_rules, share_server=None):
         """Update access rules for given share.
 
         :param context: Current context
@@ -139,6 +140,8 @@ class InfortrendNASDriver(driver.ShareDriver):
                added. access_rules already contains these rules.
         :param delete_rules: Empty List or List of access rules which should be
                removed. access_rules doesn't contain these rules.
+        :param update_rules: Empty List or List of access rules which should be
+               updated. access_rules already contains these rules.
         :param share_server: Not used by this driver.
 
         :returns: None, or a dictionary of ``access_id``, ``access_key`` as
