@@ -17,18 +17,13 @@ API for QNAP Storage.
 """
 import base64
 import functools
+from http import client as http_client
 import re
 import ssl
+from urllib import parse as urlparse
 
-try:
-    import xml.etree.cElementTree as ET
-except ImportError:
-    import xml.etree.ElementTree as ET
-
+from defusedxml import ElementTree as etree
 from oslo_log import log as logging
-import six
-from six.moves import http_client
-from six.moves import urllib
 
 from manila import exception
 from manila.i18n import _
@@ -41,7 +36,7 @@ MSG_UNEXPECT_RESP = _("Unexpected response from QNAP API")
 
 def _connection_checker(func):
     """Decorator to check session has expired or not."""
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  retries=5)
     @functools.wraps(func)
     def inner_connection_checker(self, *args, **kwargs):
@@ -50,7 +45,7 @@ def _connection_checker(func):
         try:
             return func(self, *args, **kwargs)
         except exception.ShareBackendException as e:
-            matches = pattern.match(six.text_type(e))
+            matches = pattern.match(str(e))
             if matches:
                 LOG.debug('Session might have expired.'
                           ' Trying to relogin')
@@ -84,7 +79,7 @@ class QnapAPIExecutor(object):
     def _prepare_connection(self, isSSL, ip, port):
         if isSSL:
             if hasattr(ssl, '_create_unverified_context'):
-                context = ssl._create_unverified_context()
+                context = ssl._create_unverified_context()  # nosec B323
                 connection = http_client.HTTPSConnection(ip,
                                                          port=port,
                                                          context=context)
@@ -109,7 +104,7 @@ class QnapAPIExecutor(object):
         data = response.read()
         LOG.debug('response data: %s', data)
 
-        root = ET.fromstring(data)
+        root = etree.fromstring(data)
 
         display_model_name = root.find('model/displayModelName').text
         internal_model_name = root.find('model/internalModelName').text
@@ -155,11 +150,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/authLogin.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
 
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
@@ -178,9 +173,9 @@ class QnapAPIExecutor(object):
             value = params[key]
             if value is not None:
                 if isinstance(value, list):
-                    sanitized_params[key] = [six.text_type(v) for v in value]
+                    sanitized_params[key] = [str(v) for v in value]
                 else:
-                    sanitized_params[key] = six.text_type(value)
+                    sanitized_params[key] = str(value)
         return sanitized_params
 
     @_connection_checker
@@ -193,7 +188,7 @@ class QnapAPIExecutor(object):
             'wiz_func': 'share_create',
             'action': 'add_share',
             'vol_name': create_share_name,
-            'vol_size': six.text_type(share['size']) + 'GB',
+            'vol_size': str(share['size']) + 'GB',
             'threshold': '80',
             'dedup': ('sha512'
                       if kwargs['qnap_deduplication'] is True
@@ -222,11 +217,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/wizReq.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
 
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
@@ -259,11 +254,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/disk_manage.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
 
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
@@ -283,12 +278,12 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/disk_manage.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
 
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -318,11 +313,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/disk_manage.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
 
@@ -355,11 +350,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/disk_manage.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
 
@@ -383,11 +378,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/snapshot.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -425,11 +420,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/snapshot.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
 
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
@@ -447,11 +442,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/snapshot.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         # snapshot not exist
@@ -467,22 +462,23 @@ class QnapAPIExecutor(object):
             raise exception.ShareBackendException(msg=msg)
 
     @_connection_checker
-    def clone_snapshot(self, snapshot_id, new_sharename):
+    def clone_snapshot(self, snapshot_id, new_sharename, clone_size):
         """Execute CGI to clone snapshot as share."""
         params = {
             'func': 'clone_qsnapshot',
             'by_vol': '1',
             'snapshotID': snapshot_id,
             'new_name': new_sharename,
+            'clone_size': '{}g'.format(clone_size),
             'sid': self.sid,
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/snapshot.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -499,7 +495,6 @@ class QnapAPIExecutor(object):
             'action': 'share_property',
             'sharename': share_dict['sharename'],
             'old_sharename': share_dict['old_sharename'],
-            'vol_size': six.text_type(share_dict['new_size']) + 'GB',
             'dedup': 'sha512' if share_dict['deduplication'] else 'off',
             'compression': '1' if share_dict['compression'] else '0',
             'thin_pro': '1' if share_dict['thin_provision'] else '0',
@@ -515,13 +510,15 @@ class QnapAPIExecutor(object):
             'recycle_bin_administrators_only': '0',
             'sid': self.sid,
         }
+        if share_dict.get('new_size'):
+            params['vol_size'] = str(share_dict['new_size']) + 'GB'
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/priv/privWizard.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
 
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
@@ -539,12 +536,12 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/accessrights/accessrightsRequest.cgi?%s' %
                sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -575,12 +572,12 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/accessrights/accessrightsRequest.cgi?%s' %
                sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -599,12 +596,12 @@ class QnapAPIExecutor(object):
         sanitized_params = self._sanitize_params(params)
 
         # urlencode with True parameter to parse ipv4_list
-        sanitized_params = urllib.parse.urlencode(sanitized_params, True)
+        sanitized_params = urlparse.urlencode(sanitized_params, True)
         url = ('/cgi-bin/accessrights/accessrightsRequest.cgi?%s' %
                sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -621,12 +618,12 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/accessrights/accessrightsRequest.cgi?%s' %
                sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -645,11 +642,11 @@ class QnapAPIExecutor(object):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/priv/privWizard.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
@@ -676,11 +673,11 @@ class QnapAPIExecutorTS(QnapAPIExecutor):
         }
         sanitized_params = self._sanitize_params(params)
 
-        sanitized_params = urllib.parse.urlencode(sanitized_params)
+        sanitized_params = urlparse.urlencode(sanitized_params)
         url = ('/cgi-bin/disk/snapshot.cgi?%s' % sanitized_params)
 
         res_details = self._execute_and_get_response_details(self.ip, url)
-        root = ET.fromstring(res_details['data'])
+        root = etree.fromstring(res_details['data'])
         if root.find('authPassed').text == '0':
             raise exception.ShareBackendException(msg=MSG_SESSION_EXPIRED)
         if root.find('result').text < '0':
