@@ -54,7 +54,6 @@ def destroy(context, type_id):
 
 def get_all(context, inactive=0, search_opts=None):
     """Get all non-deleted share group types."""
-    # TODO(ameade): Fix docstring
     search_opts = search_opts or {}
     filters = {}
 
@@ -121,7 +120,7 @@ def get_by_name_or_id(context, share_group_type=None):
         share_group_type_ref = get_default(context)
         if not share_group_type_ref:
             msg = _("Default share group type not found.")
-            raise exception.ShareGroupTypeNotFound(reason=msg)
+            raise exception.ShareGroupTypeNotFound(msg)
         return share_group_type_ref
 
     if uuidutils.is_uuid_like(share_group_type):
