@@ -16,17 +16,19 @@
 """
 Tests dealing with HTTP rate-limiting.
 """
+import ddt
+import http.client as http_client
+import io
 
 from oslo_serialization import jsonutils
-import six
-from six import moves
-from six.moves import http_client
 import webob
 
+from manila.api.openstack import api_version_request as api_version
 from manila.api.v1 import limits
 from manila.api import views
 import manila.context
 from manila import test
+from manila.tests.api import fakes
 
 
 TEST_LIMITS = [
@@ -36,6 +38,8 @@ TEST_LIMITS = [
     limits.Limit("PUT", "*", "", 10, limits.PER_MINUTE),
     limits.Limit("PUT", "/shares", "^/shares", 5, limits.PER_MINUTE),
 ]
+SHARE_REPLICAS_LIMIT_MICROVERSION = "2.58"
+SHARE_GROUP_QUOTA_MICROVERSION = "2.40"
 
 
 class BaseLimitTestSuite(test.TestCase):
@@ -64,24 +68,20 @@ class BaseLimitTestSuite(test.TestCase):
         return self.time
 
 
+@ddt.ddt
 class LimitsControllerTest(BaseLimitTestSuite):
     """Tests for `limits.LimitsController` class."""
 
     def setUp(self):
         """Run before each test."""
         super(LimitsControllerTest, self).setUp()
-        self.controller = limits.create_resource()
+        self.controller = limits.LimitsController()
 
-    def _get_index_request(self, accept_header="application/json"):
+    def _get_index_request(self, accept_header="application/json",
+                           microversion=api_version.DEFAULT_API_VERSION):
         """Helper to set routing arguments."""
-        request = webob.Request.blank("/")
+        request = fakes.HTTPRequest.blank('/limit', version=microversion)
         request.accept = accept_header
-        request.environ["wsgiorg.routing_args"] = (None, {
-            "action": "index",
-            "controller": "",
-        })
-        context = manila.context.RequestContext('testuser', 'testproject')
-        request.environ["manila.context"] = context
         return request
 
     def _populate_limits(self, request):
@@ -98,19 +98,20 @@ class LimitsControllerTest(BaseLimitTestSuite):
     def test_empty_index_json(self):
         """Test getting empty limit details in JSON."""
         request = self._get_index_request()
-        response = request.get_response(self.controller)
+        response = self.controller.index(request)
         expected = {
             "limits": {
                 "rate": [],
                 "absolute": {},
             },
         }
-        body = jsonutils.loads(response.body)
-        self.assertEqual(expected, body)
+        self.assertEqual(expected, response)
 
-    def test_index_json(self):
+    @ddt.data(api_version.DEFAULT_API_VERSION,
+              SHARE_REPLICAS_LIMIT_MICROVERSION)
+    def test_index_json(self, microversion):
         """Test getting limit details in JSON."""
-        request = self._get_index_request()
+        request = self._get_index_request(microversion=microversion)
         request = self._populate_limits(request)
         self.absolute_limits = {
             'limit': {
@@ -128,7 +129,21 @@ class LimitsControllerTest(BaseLimitTestSuite):
                 'share_networks': 7,
             },
         }
-        response = request.get_response(self.controller)
+
+        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
+            self.absolute_limits['limit']['share_groups'] = 20
+            self.absolute_limits['limit']['share_group_snapshots'] = 20
+            self.absolute_limits['in_use']['share_groups'] = 3
+            self.absolute_limits['in_use']['share_group_snapshots'] = 3
+
+        if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
+            self.absolute_limits['limit']['share_replicas'] = 20
+            self.absolute_limits['limit']['replica_gigabytes'] = 20
+            self.absolute_limits['in_use']['share_replicas'] = 3
+            self.absolute_limits['in_use']['replica_gigabytes'] = 3
+
+        response = self.controller.index(request)
+
         expected = {
             "limits": {
                 "rate": [
@@ -181,8 +196,19 @@ class LimitsControllerTest(BaseLimitTestSuite):
                 },
             },
         }
-        body = jsonutils.loads(response.body)
-        self.assertEqual(expected, body)
+        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
+            expected['limits']['absolute']["maxTotalShareGroups"] = 20
+            expected['limits']['absolute']["totalShareGroupsUsed"] = 3
+            expected['limits']['absolute']["maxTotalShareGroupSnapshots"] = 20
+            expected['limits']['absolute']["totalShareGroupSnapshots"] = 3
+
+        if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
+            expected['limits']['absolute']["maxTotalShareReplicas"] = 20
+            expected['limits']['absolute']["totalShareReplicasUsed"] = 3
+            expected['limits']['absolute']["maxTotalReplicaGigabytes"] = 20
+            expected['limits']['absolute']["totalReplicaGigabytesUsed"] = 3
+        # body = jsonutils.loads(response.body)
+        self.assertEqual(expected, response)
 
     def _populate_limits_diff_regex(self, request):
         """Put limit info into a request."""
@@ -197,7 +223,7 @@ class LimitsControllerTest(BaseLimitTestSuite):
         """Test getting limit details in JSON."""
         request = self._get_index_request()
         request = self._populate_limits_diff_regex(request)
-        response = request.get_response(self.controller)
+        response = self.controller.index(request)
         expected = {
             "limits": {
                 "rate": [
@@ -232,14 +258,12 @@ class LimitsControllerTest(BaseLimitTestSuite):
                 "absolute": {},
             },
         }
-        body = jsonutils.loads(response.body)
-        self.assertEqual(expected, body)
+        self.assertEqual(expected, response)
 
     def _test_index_absolute_limits_json(self, expected):
         request = self._get_index_request()
-        response = request.get_response(self.controller)
-        body = jsonutils.loads(response.body)
-        self.assertEqual(expected, body['limits']['absolute'])
+        response = self.controller.index(request)
+        self.assertEqual(expected, response['limits']['absolute'])
 
     def test_index_ignores_extra_absolute_limits_json(self):
         self.absolute_limits = {
@@ -364,36 +388,37 @@ class ParseLimitsTest(BaseLimitTestSuite):
     def test_multiple_rules(self):
         """Test that parse_limits() handles multiple rules correctly."""
         try:
-            l = limits.Limiter.parse_limits('(get, *, .*, 20, minute);'
-                                            '(PUT, /foo*, /foo.*, 10, hour);'
-                                            '(POST, /bar*, /bar.*, 5, second);'
-                                            '(Say, /derp*, /derp.*, 1, day)')
+            lim = limits.Limiter.parse_limits(
+                '(get, *, .*, 20, minute);'
+                '(PUT, /foo*, /foo.*, 10, hour);'
+                '(POST, /bar*, /bar.*, 5, second);'
+                '(Say, /derp*, /derp.*, 1, day)')
         except ValueError as e:
-            assert False, six.text_types(e)
+            assert False, str(e)
 
         # Make sure the number of returned limits are correct
-        self.assertEqual(4, len(l))
+        self.assertEqual(4, len(lim))
 
         # Check all the verbs...
         expected = ['GET', 'PUT', 'POST', 'SAY']
-        self.assertEqual(expected, [t.verb for t in l])
+        self.assertEqual(expected, [t.verb for t in lim])
 
         # ...the URIs...
         expected = ['*', '/foo*', '/bar*', '/derp*']
-        self.assertEqual(expected, [t.uri for t in l])
+        self.assertEqual(expected, [t.uri for t in lim])
 
         # ...the regexes...
         expected = ['.*', '/foo.*', '/bar.*', '/derp.*']
-        self.assertEqual(expected, [t.regex for t in l])
+        self.assertEqual(expected, [t.regex for t in lim])
 
         # ...the values...
         expected = [20, 10, 5, 1]
-        self.assertEqual(expected, [t.value for t in l])
+        self.assertEqual(expected, [t.value for t in lim])
 
         # ...and the units...
         expected = [limits.PER_MINUTE, limits.PER_HOUR,
                     limits.PER_SECOND, limits.PER_DAY]
-        self.assertEqual(expected, [t.unit for t in l])
+        self.assertEqual(expected, [t.unit for t in lim])
 
 
 class LimiterTest(BaseLimitTestSuite):
@@ -407,7 +432,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def _check(self, num, verb, url, username=None):
         """Check and yield results from checks."""
-        for x in moves.range(num):
+        for x in range(num):
             yield self.limiter.check_for_delay(verb, url, username)[0]
 
     def _check_sum(self, num, verb, url, username=None):
@@ -455,7 +480,7 @@ class LimiterTest(BaseLimitTestSuite):
 
         expected = 60.0 / 7.0
         results = self._check_sum(1, "POST", "/anything")
-        self.failUnlessAlmostEqual(expected, results, 8)
+        self.assertAlmostEqual(expected, results, 8)
 
     def test_delay_GET(self):
         """Ensure the 11th GET will result in NO delay."""
@@ -556,7 +581,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
     def _request_data(self, verb, path):
         """Get data describing a limit request verb/path."""
-        return six.b(jsonutils.dumps({"verb": verb, "path": path}))
+        return jsonutils.dumps({"verb": verb, "path": path}).encode("utf-8")
 
     def _request(self, verb, url, username=None):
         """Send request.
@@ -622,7 +647,7 @@ class FakeHttplibSocket(object):
 
     def __init__(self, response_string):
         """Initialize new `FakeHttplibSocket`."""
-        self._buffer = six.BytesIO(six.b(response_string))
+        self._buffer = io.BytesIO(response_string.encode("utf-8"))
 
     def makefile(self, _mode, _other=None):
         """Returns the socket's internal buffer."""
@@ -651,7 +676,7 @@ class FakeHttplibConnection(object):
         req.method = method
         req.headers = headers
         req.host = self.host
-        req.body = six.b(body)
+        req.body = body.encode("utf-8")
 
         resp = str(req.get_response(self.app))
         resp = "HTTP/1.0 %s" % resp
@@ -735,8 +760,9 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
         delay, error = self.proxy.check_for_delay("GET", "/delayed")
         error = error.strip()
 
-        expected = ("60.00", six.b("403 Forbidden\n\nOnly 1 GET request(s) "
-                                   "can be made to /delayed every minute."))
+        expected = ("60.00", (
+            "403 Forbidden\n\nOnly 1 GET request(s) can be made to /delayed "
+            "every minute.").encode("utf-8"))
 
         self.assertEqual(expected, (delay, error))
 
@@ -782,6 +808,7 @@ class LimitsViewBuilderTest(test.TestCase):
         }
 
     def test_build_limits(self):
+        request = fakes.HTTPRequest.blank('/')
         tdate = "2011-07-21T18:17:06Z"
         expected_limits = {
             "limits": {
@@ -816,15 +843,17 @@ class LimitsViewBuilderTest(test.TestCase):
             }
         }
 
-        output = self.view_builder.build(self.rate_limits,
+        output = self.view_builder.build(request,
+                                         self.rate_limits,
                                          self.absolute_limits)
-        self.assertDictMatch(expected_limits, output)
+        self.assertDictEqual(expected_limits, output)
 
     def test_build_limits_empty_limits(self):
+        request = fakes.HTTPRequest.blank('/')
         expected_limits = {"limits": {"rate": [], "absolute": {}}}
         abs_limits = {}
         rate_limits = []
 
-        output = self.view_builder.build(rate_limits, abs_limits)
+        output = self.view_builder.build(request, rate_limits, abs_limits)
 
-        self.assertDictMatch(expected_limits, output)
+        self.assertDictEqual(expected_limits, output)
