@@ -14,8 +14,8 @@
 #    under the License.
 
 from oslo_log import log
-import six
 
+from manila.common import constants
 from manila.share import driver
 from manila.tests import fake_service_instance
 
@@ -50,7 +50,7 @@ class FakeShareDriver(driver.ShareDriver):
     def manage_existing(self, share, driver_options, share_server=None):
         LOG.debug("Fake share driver: manage")
         LOG.debug("Fake share driver: driver options: %s",
-                  six.text_type(driver_options))
+                  str(driver_options))
         return {'size': 1}
 
     def unmanage(self, share, share_server=None):
@@ -74,8 +74,11 @@ class FakeShareDriver(driver.ShareDriver):
         return ['/fake/path', '/fake/path2']
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None):
-        return ['/fake/path', '/fake/path2']
+                                   share_server=None, parent_share=None):
+        return {
+            'export_locations': ['/fake/path', '/fake/path2'],
+            'status': constants.STATUS_AVAILABLE,
+        }
 
     def delete_share(self, context, share, share_server=None):
         pass
@@ -115,3 +118,9 @@ class FakeShareDriver(driver.ShareDriver):
 
     def delete_share_group(self, context, group_id, share_server=None):
         pass
+
+    def get_share_status(self, share, share_server=None):
+        return {
+            'export_locations': ['/fake/path', '/fake/path2'],
+            'status': constants.STATUS_AVAILABLE,
+        }
