@@ -12,10 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import netaddr
+from urllib import parse
+
+import requests
+
 from oslo_log import log
 from oslo_serialization import jsonutils
-from six.moves import http_client
-from six.moves.urllib import parse
 
 LOG = log.getLogger(__name__)
 
@@ -27,8 +30,8 @@ class OpenStackApiException(Exception):
             message = 'Unspecified error'
 
         if response:
-            _status = response.status
-            _body = response.read()
+            _status = response.status_code
+            _body = response.text
 
             message = ('%(message)s\nStatus Code: %(_status)s\n'
                        'Body: %(_body)s') % {
@@ -71,68 +74,58 @@ class TestOpenStackClient(object):
 
     """
 
-    def __init__(self, auth_user, auth_key, auth_uri):
+    def __init__(self, auth_user, auth_key, endpoint):
         super(TestOpenStackClient, self).__init__()
         self.auth_result = None
         self.auth_user = auth_user
         self.auth_key = auth_key
-        self.auth_uri = auth_uri
+        self.endpoint = endpoint
         # default project_id
         self.project_id = 'openstack'
 
-    def request(self, url, method='GET', body=None, headers=None):
+    def request(self, url, method='GET', body=None, headers=None,
+                ssl_verify=True, stream=False):
         _headers = {'Content-Type': 'application/json'}
         _headers.update(headers or {})
 
         parsed_url = parse.urlparse(url)
-        port = parsed_url.port
+        port = parsed_url.port or ''
         hostname = parsed_url.hostname
+        if netaddr.valid_ipv6(hostname):
+            hostname = "[%s]" % hostname
         scheme = parsed_url.scheme
-
-        if scheme == 'http':
-            conn = http_client.HTTPConnection(hostname,
-                                              port=port)
-        elif scheme == 'https':
-            conn = http_client.HTTPSConnection(hostname,
-                                               port=port)
-        else:
-            raise OpenStackApiException("Unknown scheme: %s" % url)
-
         relative_url = parsed_url.path
         if parsed_url.query:
             relative_url = relative_url + "?" + parsed_url.query
-        LOG.info("Doing %(method)s on %(relative_url)s",
-                 {"method": method, "relative_url": relative_url})
-        if body:
-            LOG.info("Body: %s", body)
+        LOG.debug("Doing %(method)s on %(relative_url)s, body: %(body)s",
+                  {"method": method, "relative_url": relative_url,
+                   "body": body or {}})
 
-        conn.request(method, relative_url, body, _headers)
-        response = conn.getresponse()
+        _url = "%s://%s:%s%s" % (scheme, hostname, port, relative_url)
+
+        response = requests.request(method, _url, data=body, headers=_headers,
+                                    verify=ssl_verify, stream=stream)
         return response
 
     def _authenticate(self):
         if self.auth_result:
             return self.auth_result
 
-        auth_uri = self.auth_uri
         headers = {'X-Auth-User': self.auth_user,
                    'X-Auth-Key': self.auth_key,
                    'X-Auth-Project-Id': self.project_id}
-        response = self.request(auth_uri,
+        response = self.request(self.endpoint,
                                 headers=headers)
 
-        http_status = response.status
-        LOG.debug("%(auth_uri)s => code %(http_status)s.",
-                  {"auth_uri": auth_uri, "http_status": http_status})
+        http_status = response.status_code
+        LOG.debug("%(endpoint)s => code %(http_status)s.",
+                  {"endpoint": self.endpoint,
+                   "http_status": http_status})
 
         if http_status == 401:
             raise OpenStackApiAuthenticationException(response=response)
 
-        auth_headers = {}
-        for k, v in response.getheaders():
-            auth_headers[k.lower()] = v
-
-        self.auth_result = auth_headers
+        self.auth_result = response.headers
         return self.auth_result
 
     def api_request(self, relative_uri, check_response_status=None, **kwargs):
@@ -147,7 +140,7 @@ class TestOpenStackClient(object):
 
         response = self.request(full_uri, **kwargs)
 
-        http_status = response.status
+        http_status = response.status_code
         LOG.debug("%(relative_uri)s => code %(http_status)s.",
                   {"relative_uri": relative_uri, "http_status": http_status})
 
@@ -165,7 +158,7 @@ class TestOpenStackClient(object):
         return response
 
     def _decode_json(self, response):
-        body = response.read()
+        body = response.text
         LOG.debug("Decoding JSON: %s.", (body))
         if body:
             return jsonutils.loads(body)
