@@ -45,6 +45,15 @@ class FakeNeutronClient(object):
     def list_ports(self, **search_opts):
         pass
 
+    def create_port_binding(self, port_id, body):
+        return body
+
+    def delete_port_binding(self, port_id, host_id):
+        pass
+
+    def activate_port_binding(self, port_id, host_id):
+        pass
+
     def list_networks(self):
         pass
 
@@ -90,7 +99,8 @@ class NeutronclientTestCase(test.TestCase):
         fake_context = 'fake_context'
         data = {
             'neutron': {
-                'endpoint_type': 'foo_endpoint_type',
+                'url': 'http://localhost:9696',
+                'endpoint_type': 'internalURL',
                 'region_name': 'foo_region_name',
             }
         }
@@ -102,7 +112,6 @@ class NeutronclientTestCase(test.TestCase):
 
         mock_client_loader.assert_called_once_with(
             client_class=neutron_api.clientv20.Client,
-            exception_module=neutron_api.neutron_client_exc,
             cfg_group=neutron_api.NEUTRON_GROUP
         )
         mock_client_loader.return_value.get_client.assert_called_once_with(
@@ -110,13 +119,15 @@ class NeutronclientTestCase(test.TestCase):
             fake_context,
             endpoint_type=data['neutron']['endpoint_type'],
             region_name=data['neutron']['region_name'],
+            endpoint_override=data['neutron']['url'],
         )
 
     def test_with_auth_obj(self):
         fake_context = 'fake_context'
         data = {
             'neutron': {
-                'endpoint_type': 'foo_endpoint_type',
+                'url': 'http://localhost:9696',
+                'endpoint_type': 'internalURL',
                 'region_name': 'foo_region_name',
             }
         }
@@ -133,6 +144,7 @@ class NeutronclientTestCase(test.TestCase):
             fake_context,
             endpoint_type=data['neutron']['endpoint_type'],
             region_name=data['neutron']['region_name'],
+            endpoint_override=data['neutron']['url'],
         )
 
 
@@ -276,6 +288,35 @@ class NeutronApiTest(test.TestCase):
         self.neutron_api.client.delete_port.assert_called_once_with(port_id)
         self.assertTrue(clientv20.Client.called)
 
+    def test_delete_port_NeutronClientException(self):
+        # Set up test data
+        self.mock_object(
+            self.neutron_api.client, 'delete_port',
+            mock.Mock(side_effect=neutron_client_exc.NeutronClientException()))
+        port_id = 'test port id'
+
+        self.assertRaises(exception.NetworkException,
+                          self.neutron_api.delete_port,
+                          port_id)
+
+        # Verify results
+        self.neutron_api.client.delete_port.assert_called_once_with(port_id)
+        self.assertTrue(clientv20.Client.called)
+
+    def test_delete_port_PortNotFoundClient(self):
+        # Set up test data
+        self.mock_object(
+            self.neutron_api.client, 'delete_port',
+            mock.Mock(side_effect=neutron_client_exc.PortNotFoundClient()))
+        port_id = 'test port id'
+
+        # Execute method 'delete_port'
+        self.neutron_api.delete_port(port_id)
+
+        # Verify results
+        self.neutron_api.client.delete_port.assert_called_once_with(port_id)
+        self.assertTrue(clientv20.Client.called)
+
     def test_list_ports(self):
         # Set up test data
         search_opts = {'test_option': 'test_value'}
@@ -533,6 +574,30 @@ class NeutronApiTest(test.TestCase):
             port_id, {'port': fixed_ips})
         self.assertTrue(clientv20.Client.called)
 
+    def test_bind_port_to_host(self):
+        port_id = 'test_port'
+        host = 'test_host'
+        vnic_type = 'test_vnic_type'
+
+        port = self.neutron_api.bind_port_to_host(port_id, host, vnic_type)
+
+        self.assertEqual(host, port['host'])
+        self.assertTrue(clientv20.Client.called)
+
+    def test_delete_port_binding(self):
+        port_id = 'test_port'
+        host = 'test_host'
+        self.neutron_api.delete_port_binding(port_id, host)
+        self.assertTrue(clientv20.Client.called)
+
+    def test_activate_port_binding(self):
+        port_id = 'test_port'
+        host = 'test_host'
+
+        self.neutron_api.activate_port_binding(port_id, host)
+
+        self.assertTrue(clientv20.Client.called)
+
     def test_router_update_routes(self):
         # Set up test data
         router_id = 'test_router'
