@@ -218,7 +218,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -253,7 +254,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -288,7 +290,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 },
             ]
@@ -345,7 +348,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -381,7 +385,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -417,7 +422,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -453,7 +459,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -489,7 +496,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None,
                     },
                 },
             ]
@@ -558,7 +566,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -593,7 +602,8 @@ class HostManagerTestCase(test.TestCase):
                         'network_allocation_update_support': False,
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
-                        'share_replicas_migration_support': False
+                        'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 },
             ]
@@ -657,6 +667,7 @@ class HostManagerTestCase(test.TestCase):
                         'share_server_multiple_subnet_support': False,
                         'mount_point_name_support': False,
                         'share_replicas_migration_support': False,
+                        'encryption_support': None
                     },
                 },
             ]
@@ -1240,9 +1251,10 @@ class PoolStateTestCase(test.TestCase):
     @ddt.unpack
     def test_update_from_share_capability(self, share_capability, instances):
         fake_context = context.RequestContext('user', 'project', is_admin=True)
+        sizes = [instance['size'] or 0 for instance in instances]
         self.mock_object(
-            db, 'share_instance_get_all_by_host',
-            mock.Mock(return_value=instances))
+            db, 'share_instance_sizes_sum_by_host',
+            mock.Mock(return_value=sum(sizes)))
         fake_pool = host_manager.PoolState('host1', None, 'pool0')
         self.assertIsNone(fake_pool.free_capacity_gb)
 
@@ -1265,19 +1277,19 @@ class PoolStateTestCase(test.TestCase):
             self.assertEqual(thin_provisioned, fake_pool.thin_provisioning)
             if 'provisioned_capacity_gb' not in share_capability or (
                     share_capability['provisioned_capacity_gb'] is None):
-                db.share_instance_get_all_by_host.assert_called_once_with(
-                    fake_context, fake_pool.host, with_share_data=True)
+                db.share_instance_sizes_sum_by_host.assert_called_once_with(
+                    fake_context, fake_pool.host)
                 if len(instances) > 0:
                     self.assertEqual(4, fake_pool.provisioned_capacity_gb)
                 else:
                     self.assertEqual(0, fake_pool.provisioned_capacity_gb)
             else:
-                self.assertFalse(db.share_instance_get_all_by_host.called)
+                self.assertFalse(db.share_instance_sizes_sum_by_host.called)
                 self.assertEqual(share_capability['provisioned_capacity_gb'],
                                  fake_pool.provisioned_capacity_gb)
         else:
             self.assertFalse(fake_pool.thin_provisioning)
-            self.assertFalse(db.share_instance_get_all_by_host.called)
+            self.assertFalse(db.share_instance_sizes_sum_by_host.called)
             if 'provisioned_capacity_gb' not in share_capability or (
                     share_capability['provisioned_capacity_gb'] is None):
                 self.assertIsNone(fake_pool.provisioned_capacity_gb)
