@@ -274,6 +274,8 @@ class GlusterfsNativeShareDriverTestCase(test.TestCase):
             'security_service_update_support': False,
             'share_server_multiple_subnet_support': False,
             'network_allocation_update_support': False,
+            'share_replicas_migration_support': False,
+            'encryption_support': None,
         }
         self.assertEqual(test_data, self._driver._stats)
 
