@@ -243,7 +243,8 @@ class InStorageShareDriverTestCase(test.TestCase):
             instorage.InStorageAssistant, 'update_access'
         )
 
-        self.driver.update_access(self._ctxt, self.share_instance, [], [], [])
+        self.driver.update_access(
+            self._ctxt, self.share_instance, [], [], [], [])
 
         mock_ua.assert_called_once_with(
             'fakeinstanceid', 'fake_proto', [], [], []
