@@ -72,6 +72,7 @@ ROOT_AGGREGATES = ('root_aggr_1', 'root_aggr_2')
 ROOT_VOLUME_AGGREGATE = 'manila1'
 SECURITY_CERT_DEFAULT_EXPIRE_DAYS = 365
 SECURITY_CERT_LARGE_EXPIRE_DAYS = 3652
+DELETE_RETENTION_HOURS = 12
 ROOT_VOLUME = 'root'
 CLUSTER_NODE = 'cluster1_01'
 CLUSTER_NODES = ('cluster1_01', 'cluster1_02')
@@ -115,6 +116,7 @@ FPOLICY_EXT_TO_EXCLUDE = 'jpg,mp3'
 FPOLICY_EXT_TO_EXCLUDE_LIST = ['jpg', 'mp3']
 BACKUP_TYPE = "fake_backup_type"
 MOUNT_POINT_NAME = 'fake_mp'
+VOLUME_EFFICIENCY_POLICY_NAME = 'fake_volume_efficiency_policy'
 
 JOB_ID = '123'
 JOB_STATE = 'success'
@@ -127,6 +129,10 @@ CLIENT_KWARGS = {
     'transport_type': 'https',
     'ssl_cert_path': '/etc/ssl/certs/',
     'password': 'pass',
+    'private_key_file': '/fake_private_key.pem',
+    'certificate_file': '/fake_certificate.pem',
+    'ca_certificate_file': '/fake_ca_certificate.crt',
+    'certificate_host_validation': False,
     'port': '443',
     'api_trace_pattern': '(.*)',
 }
@@ -193,6 +199,22 @@ SHARE_FLEXGROUP = {
 }
 
 SHARE_INSTANCE = {
+    'id': SHARE_INSTANCE_ID,
+    'share_id': SHARE_ID,
+    'host': MANILA_HOST_NAME,
+    'project_id': TENANT_ID,
+    'mount_point_name': MOUNT_POINT_NAME,
+    'name': SHARE_INSTANCE_NAME,
+    'size': SHARE_SIZE,
+    'share_proto': 'fake',
+    'share_type_id': SHARE_TYPE_ID,
+    'share_network_id': '5dfe0898-e2a1-4740-9177-81c7d26713b0',
+    'share_server_id': '7e6a2cc8-871f-4b1d-8364-5aad0f98da86',
+    'replica_state': constants.REPLICA_STATE_ACTIVE,
+    'status': constants.STATUS_AVAILABLE
+}
+
+SHARE_INSTANCE_WITH_ENCRYPTION = {
     'id': SHARE_INSTANCE_ID,
     'share_id': SHARE_ID,
     'host': MANILA_HOST_NAME,
@@ -206,6 +228,7 @@ SHARE_INSTANCE = {
     'share_server_id': '7e6a2cc8-871f-4b1d-8364-5aad0f98da86',
     'replica_state': constants.REPLICA_STATE_ACTIVE,
     'status': constants.STATUS_AVAILABLE,
+    'encryption_key_ref': 'fake_key_ref'
 }
 
 FLEXVOL_TO_MANAGE = {
@@ -263,6 +286,12 @@ EXTRA_SPEC = {
     'netapp:tcp_max_xfer_size': 100,
     'netapp:udp_max_xfer_size': 100,
     'netapp:adaptive_qos_policy_group': None,
+    'netapp:snaplock_type': "compliance",
+    'netapp:snaplock_autocommit_period': '4months',
+    'netapp:snaplock_min_retention_period': '30minutes',
+    'netapp:snaplock_max_retention_period': '2years',
+    'netapp:snaplock_default_retention_period': '2months'
+
 }
 
 EXTRA_SPEC_WITH_REPLICATION = copy.copy(EXTRA_SPEC)
@@ -404,30 +433,51 @@ PROVISIONING_OPTIONS_STRING = {
     'snapshot_policy': 'default',
     'language': 'en-US',
     'max_files': 5000,
+    'max_files_multiplier': 4.2,
     'adaptive_qos_policy_group': None,
     'fpolicy_extensions_to_exclude': None,
     'fpolicy_extensions_to_include': None,
     'fpolicy_file_operations': None,
+    'efficiency_policy': None,
+    'snaplock_type': None,
+    'snaplock_autocommit_period': None,
+    'snaplock_min_retention_period': None,
+    'snaplock_max_retention_period': None,
+    'snaplock_default_retention_period': None,
 }
 
 PROVISIONING_OPTIONS_STRING_MISSING_SPECS = {
     'snapshot_policy': 'default',
     'language': 'en-US',
     'max_files': None,
+    'max_files_multiplier': None,
     'adaptive_qos_policy_group': None,
     'fpolicy_extensions_to_exclude': None,
     'fpolicy_extensions_to_include': None,
     'fpolicy_file_operations': None,
+    'efficiency_policy': None,
+    'snaplock_type': None,
+    'snaplock_autocommit_period': None,
+    'snaplock_min_retention_period': None,
+    'snaplock_max_retention_period': None,
+    'snaplock_default_retention_period': None,
 }
 
 PROVISIONING_OPTIONS_STRING_DEFAULT = {
     'snapshot_policy': None,
     'language': None,
     'max_files': None,
+    'max_files_multiplier': None,
     'adaptive_qos_policy_group': None,
     'fpolicy_extensions_to_exclude': None,
     'fpolicy_extensions_to_include': None,
     'fpolicy_file_operations': None,
+    'efficiency_policy': None,
+    'snaplock_type': None,
+    'snaplock_autocommit_period': None,
+    'snaplock_min_retention_period': None,
+    'snaplock_max_retention_period': None,
+    'snaplock_default_retention_period': None,
 }
 
 SHORT_BOOLEAN_EXTRA_SPEC = {
@@ -438,7 +488,9 @@ STRING_EXTRA_SPEC = {
     'netapp:snapshot_policy': 'default',
     'netapp:language': 'en-US',
     'netapp:max_files': 5000,
+    'netapp:max_files_multiplier': 4.2,
     'netapp:adaptive_qos_policy_group': None,
+    'netapp:efficiency_policy': None,
 }
 
 SHORT_STRING_EXTRA_SPEC = {
@@ -845,6 +897,7 @@ LIF_NAMES = []
 LIF_ADDRESSES = ['10.10.10.10', '10.10.10.20']
 LIFS = (
     {'address': LIF_ADDRESSES[0],
+     'administrative-status': 'up',
      'home-node': CLUSTER_NODES[0],
      'home-port': 'e0c',
      'interface-name': 'os_132dbb10-9a36-46f2-8d89-3d909830c356',
@@ -853,6 +906,7 @@ LIFS = (
      'vserver': VSERVER1
      },
     {'address': LIF_ADDRESSES[1],
+     'administrative-status': 'up',
      'home-node': CLUSTER_NODES[1],
      'home-port': 'e0c',
      'interface-name': 'os_7eabdeed-bad2-46ea-bd0f-a33884c869e0',
@@ -965,6 +1019,7 @@ FLEXGROUP_POOL = {
     'security_service_update_support': True,
     'netapp_flexgroup': True,
     'netapp_cluster_name': 'fake_cluster_name',
+    'netapp_snaplock_type': ['compliance', 'enterprise'],
 }
 
 FLEXGROUP_AGGR_SET = set(FLEXGROUP_POOL_OPT[FLEXGROUP_POOL_NAME])
@@ -985,6 +1040,7 @@ SSC_INFO = {
         'netapp_hybrid_aggregate': 'false',
         'netapp_aggregate': AGGREGATES[0],
         'netapp_flexgroup': False,
+        'netapp_snaplock_type': 'compliance',
     },
     AGGREGATES[1]: {
         'netapp_raid_type': 'raid_dp',
@@ -992,6 +1048,7 @@ SSC_INFO = {
         'netapp_hybrid_aggregate': 'true',
         'netapp_aggregate': AGGREGATES[1],
         'netapp_flexgroup': False,
+        'netapp_snaplock_type': 'enterprise',
     }
 }
 
@@ -1000,11 +1057,13 @@ SSC_INFO_MAP = {
         'netapp_raid_type': 'raid4',
         'netapp_disk_type': ['FCAL'],
         'netapp_hybrid_aggregate': 'false',
+        'netapp_snaplock_type': 'compliance',
     },
     AGGREGATES[1]: {
         'netapp_raid_type': 'raid_dp',
         'netapp_disk_type': ['SATA', 'SSD'],
         'netapp_hybrid_aggregate': 'true',
+        'netapp_snaplock_type': 'enterprise',
     }
 }
 
@@ -1049,6 +1108,9 @@ POOLS = [
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
         'netapp_cluster_name': 'fake_cluster_name',
+        'netapp_snaplock_type': 'compliance',
+        'share_replicas_migration_support': True,
+        'encryption_support': ['share_server'],
     },
     {
         'pool_name': AGGREGATES[1],
@@ -1078,6 +1140,9 @@ POOLS = [
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
         'netapp_cluster_name': 'fake_cluster_name',
+        'netapp_snaplock_type': 'compliance',
+        'share_replicas_migration_support': True,
+        'encryption_support': ['share_server'],
     },
 ]
 
@@ -1108,6 +1173,8 @@ POOLS_VSERVER_CREDS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'share_replicas_migration_support': True,
+        'encryption_support': ['share_server'],
     },
     {
         'pool_name': AGGREGATES[1],
@@ -1131,6 +1198,8 @@ POOLS_VSERVER_CREDS = [
         'security_service_update_support': True,
         'share_server_multiple_subnet_support': True,
         'netapp_flexgroup': False,
+        'share_replicas_migration_support': True,
+        'encryption_support': ['share_server'],
     },
 ]
 
@@ -1140,12 +1209,14 @@ SSC_AGGREGATES = [
         'raid-type': 'raid4',
         'is-hybrid': False,
         'is-home': False,
+        'snaplock-type': 'compliance',
     },
     {
         'name': AGGREGATES[1],
         'raid-type': 'raid_dp',
         'is-hybrid': True,
         'is-home': True,
+        'snaplock-type': 'enterprise',
     },
 ]
 
@@ -1581,6 +1652,16 @@ SERVER_METADATA = {
     'host': 'fake_host',
 }
 
+SERVER_METADATA_WITH_ENCRYPTION = {
+    'share_type_id': 'fake_id',
+    'host': 'fake_host',
+    'encryption_key_ref': 'fake_key',
+    'keystone_url': 'fake_keystone_url',
+    'application_credential_id': 'fake_app_cred_id',
+    'application_credential_secret': 'fake_app_cred_secret',
+    'request_host': 'fake_host@pool'
+}
+
 PROCESSOR_COUNTERS = [
     {
         'node-name': 'cluster1-01',
@@ -1919,6 +2000,11 @@ def get_config_cmode():
     config.netapp_transport_type = CLIENT_KWARGS['transport_type']
     config.netapp_ssl_cert_path = CLIENT_KWARGS['ssl_cert_path']
     config.netapp_server_port = CLIENT_KWARGS['port']
+    config.netapp_private_key_file = CLIENT_KWARGS['private_key_file']
+    config.netapp_certificate_file = CLIENT_KWARGS['certificate_file']
+    config.netapp_ca_certificate_file = CLIENT_KWARGS['ca_certificate_file']
+    config.netapp_certificate_host_validation = \
+        CLIENT_KWARGS['certificate_host_validation']
     config.netapp_volume_name_template = VOLUME_NAME_TEMPLATE
     config.netapp_aggregate_name_search_pattern = AGGREGATE_NAME_SEARCH_PATTERN
     config.netapp_vserver_name_template = VSERVER_NAME_TEMPLATE
