@@ -717,5 +717,6 @@ class QuotaEngineTestCase(test.TestCase):
             sorted(['gigabytes', 'per_share_gigabytes', 'replica_gigabytes',
                     'share_group_snapshots', 'share_groups', 'share_networks',
                     'share_replicas', 'shares', 'snapshot_gigabytes',
-                    'snapshots', 'backups', 'backup_gigabytes']),
+                    'snapshots', 'backups', 'backup_gigabytes',
+                    'encryption_keys']),
             quota.QUOTAS.resources)
