@@ -17,7 +17,7 @@
 PRE_COMMIT_SCRIPT=.git/hooks/pre-commit
 
 make_hook() {
-    echo "exec ./run_tests.sh -N -p" >> $PRE_COMMIT_SCRIPT
+    echo "exec tox -e fast8" >> $PRE_COMMIT_SCRIPT
     chmod +x $PRE_COMMIT_SCRIPT
 
     if [ -w $PRE_COMMIT_SCRIPT -a -x $PRE_COMMIT_SCRIPT ]; then
@@ -39,4 +39,3 @@ if [ ! -d ".git" ]; then
 else
     make_hook
 fi
-
